Structs
- Feature
Context - Context for a single feature within the generated file.
- File
Context - Context for rendering an entire generated file.
- Struct
Context - Context for a struct type declaration.
- Struct
Field Context - Context for a single field within a struct type.
- Variable
Context - Context for a single variable within a feature.
Functions
- render
- Render a template string with the given file context.