Module template

Module template 

Structs

FeatureContext
Context for a single feature within the generated file.
FileContext
Context for rendering an entire generated file.
StructContext
Context for a struct type declaration.
StructFieldContext
Context for a single field within a struct type.
VariableContext
Context for a single variable within a feature.

Functions

render
Render a template string with the given file context.